@@ -5,7 +5,7 @@ import base64
 import json
 from subprocess import Popen, PIPE
 
-from artify import __version__
+from artify import __version__, changelog
 
 from artify import nexus
 from artify import deploy
@@ -15,6 +15,7 @@ from artify import generate_file
 from artify import extract_commands
 from artify import initialize
 from artify import archive
+from artify import changelog
 
 debug = 0;
 
@@ -43,7 +44,6 @@ group_id = ''
 auth = ''
 
 path = ''
-
 # Variables - Nexus
 
 # Variables - Deploy AWX
@@ -254,6 +254,8 @@ def main(argv):
                 print("-w, --rootdir      Root directory is a directory that will be the root directory of the archive.")
                 print("-d, --basedir      Base directory is the directory where we start archiving from.")
                 return sys.exit(0)
+            elif arg == "changelog":
+                print("python -m artify -c changelog --added add login functionality --changed=update from oauth2 to keycloak")
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
@@ -479,6 +481,8 @@ def main(argv):
     elif action == 'document':
         #document artifact changes
         pass
+    elif action == 'changelog':
+        changelog.update_changelog()
     elif action == 'extract':
         extract_commands.extract()   
     elif action == 'initialize':
