@@ -117,13 +117,24 @@ def upload_nexus_maven():
     extension = ''
     versionnumber = ''
     
+    path = __main__.os.path.abspath(__main__.os.getcwd())
+    
     params = (('repository', __main__.repository_name),)
    
     #finalpath = __main__.work_directory + '/' + __main__.artifact_name
     finalpath = __main__.os.path.join(__main__.work_directory, __main__.artifact_name)
     
     if __main__.artifact_name2:
-        finalpath2 = __main__.os.path.join(__main__.work_directory, __main__.artifact_name2)
+        finalpath2 = __main__.os.path.join(path, __main__.artifact_name2)
+    else:
+        #Check if manifest.yml exist then try to upload
+        finalpath2 = __main__.os.path.join(path, 'manifest.yml')
+        if  __main__.os.path.exists(finalpath2):
+            __main__.artifact_name2 = 'manifest.yml'
+        else:
+            finalpath2 = None
+            
+        
     
     if ('tar.gz' in __main__.artifact_name):
         pass
