@@ -5,6 +5,8 @@ from artify import change_version
 def commit_push_changes(message):
     print("INFO: Committing changes")
     
+    version = None
+    
     git_tag_command = ''
     git_push_command = ''
     
@@ -54,6 +56,11 @@ def commit_push_changes(message):
             filepath = __main__.os.path.join(path,'pubspec.yaml')
             version = change_version.get_version(filepath, 'standard')
             
+        if __main__.os.path.exists(__main__.os.path.join(path, 'version.txt')):
+            __main__.arch_type = 'other'
+            filepath = __main__.os.path.join(path, 'version.txt')
+            version = change_version.get_version(filepath, 'custom')
+
         if __main__.os.path.exists(__main__.os.path.join(path, 'setup.py')):
             __main__.arch_type = 'other'
             filepath = __main__.os.path.join(path, 'setup.py')
@@ -129,4 +136,4 @@ def commit_push_changes(message):
  
     ##git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(os.environ.get('GITLAB_USER_LOGIN'), os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, os.environ.get('CI_COMMIT_BRANCH'))
     process_git_push = __main__.Popen(git_push_command, shell=True, stdout=__main__.PIPE, cwd=path)
-    print("INFO: Push result: ", process_git_push.communicate()[0])
\ No newline at end of file
+    print("INFO: Push result: ", process_git_push.communicate()[0])
